@@ -1,7 +1,7 @@
 #' Stata color palettes (discrete)
 #'
 #' Stata color palettes. See Stata documentation for a description of
-#' the schemes, \url{http://www.stata.com/help.cgi?schemes}.
+#' the schemes, \url{https://www.stata.com/help.cgi?schemes}.
 #'
 #' All these palettes support up to 15 values.
 #'
@@ -43,15 +43,16 @@ scale_fill_stata <- function(scheme="s2color", ...) {
 #' @rdname scale_stata
 scale_color_stata <- scale_colour_stata
 
+#' @importFrom ggplot2 margin
 theme_stata_base <- function(base_size = 11, base_family = "sans") {
   ## Sizes
   relsz <- sapply(as.numeric(stata_gsize), `/`,
                   y = as.numeric(stata_gsize$medium))
   names(relsz) <- names(stata_gsize)
   theme_foundation() +
-  theme(line = element_line(size = 0.5, linetype = 1, lineend = "butt",
+  theme(line = element_line(linewidth = 0.5, linetype = 1, lineend = "butt",
                             colour = "black"),
-        rect = element_rect(size = 0.5, linetype = 1, fill = "white",
+        rect = element_rect(linewidth = 0.5, linetype = 1, fill = "white",
                             colour = "black"),
         text = element_text(family = base_family,
                             face = "plain",
@@ -76,7 +77,7 @@ theme_stata_base <- function(base_size = 11, base_family = "sans") {
         axis.ticks.length = unit(4 / 11, "lines"),
         legend.background =
           element_rect(linetype = 1,
-                       size = rel(stata_linewidths[["thin"]])),
+                       linewidth = rel(stata_linewidths[["thin"]])),
         legend.spacing = unit(1.2 / 100, "npc"),
         legend.key = element_rect(linetype = 0),
         legend.key.size = unit(1.2, "lines"),
@@ -224,7 +225,7 @@ theme_stata_colors <- function(scheme="s2color") {
 #' defaults, and more effort was made to match the colors and sizes
 #' of major elements than in matching the margins.
 #'
-#' @references \url{http://www.stata.com/help.cgi?schemes}
+#' @references \url{https://www.stata.com/help.cgi?schemes}
 #'
 #' @example inst/examples/ex-theme_stata.R
 theme_stata <- function(base_size = 11, base_family = "sans",
@@ -239,6 +240,9 @@ theme_stata <- function(base_size = 11, base_family = "sans",
 #' Shape palette based on the symbol palette in Stata used in scheme s2mono.
 #' This palette supports up to 10 values.
 #'
+#' This palette uses unicode symbols for the shapes. This means that it will
+#' not work for all graphics devices.
+#'
 #' @export
 #' @family shapes stata
 #' @seealso See \code{\link{scale_shape_stata}()} for examples.
@@ -264,10 +268,14 @@ stata_shape_pal <- function() {
 #'
 #' See \code{\link{stata_shape_pal}()} for details.
 #'
+#' This scale uses unicode symbols for the shapes. This means that it will
+#' not work for all graphics devices.
+#'
 #' @inheritParams ggplot2::scale_x_discrete
 #' @family shape stata
 #' @export
 #' @example inst/examples/ex-scale_shape_stata.R
+#' @importFrom ggplot2 discrete_scale
 scale_shape_stata <- function(...) {
   discrete_scale("shape", "stata", stata_shape_pal(), ...)
 }
