@@ -1,15 +1,15 @@
 #' Tableau Color Palettes (discrete)
 #'
-#' Color palettes used in \href{http://www.tableausoftware.com/}{Tableau}.
+#' Color palettes used in \href{https://www.tableau.com/}{Tableau}.
 #'
 #' @details Tableau provides three types of color palettes:
 #' \code{"regular"} (discrete, qualitative categories),
 #' \code{"ordered-sequential"}, and \code{"ordered-diverging"}.
 #'
-#' \itemize{
-#' \item{\code{"regular"}}{\Sexpr[results=rd]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["regular"]]))}}
-#' \item{\code{"ordered-diverging"}}{\Sexpr[results=rd]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["ordered-diverging"]]))}}
-#' \item{\code{"ordered-sequential"}}{\Sexpr[results=rd]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["ordered-sequential"]]))}}
+#' \describe{
+#' \item{Regular palettes}{\Sexpr[results=rd,stage=build]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["regular"]]))}}
+#' \item{Ordered diverging palettes}{\Sexpr[results=rd,stage=build]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["ordered-diverging"]]))}}
+#' \item{Ordered sequential palettes}{\Sexpr[results=rd,stage=build]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["ordered-sequential"]]))}}
 #' }
 #'
 #' @export
@@ -23,8 +23,7 @@
 #'
 #' Maureen Stone, 'Designing Colors for Data' (slides), at the
 #' International Symposium on Computational Aesthetics in Graphics,
-#' Visualization, and Imaging, Banff, AB, Canada, June 22, 2007
-#' \url{http://www.stonesc.com/slides/CompAe\%202007.pdf}.
+#' Visualization, and Imaging, Banff, AB, Canada, June 22, 2007.
 #'
 #' Heer, Jeffrey and Maureen Stone, 2012 'Color Naming Models for
 #' Color Selection, Image Editing and Palette Design', ACM Human
@@ -47,10 +46,11 @@ tableau_color_pal <- function(palette = "Tableau 10",
   max_n <- length(values)
   f <- function(n) {
     check_pal_n(n, max_n)
+    values <- values[seq_len(n)]
     if (direction < 0) {
       values <- rev(values)
     }
-    values[seq_len(n)]
+    values
   }
   attr(f, "max_n") <- length(values)
   f
@@ -63,12 +63,12 @@ tableau_color_pal <- function(palette = "Tableau 10",
 #' and \funclink{scale_colour_gradient2_tableau} for the diverging continuous
 #' color scales from Tableu.
 #'
-#' @inheritParams ggplot2::scale_colour_hue
 #' @param palette Palette name. See \funclink{tableau_color_pal}
 #'   for available palettes.
 #' @param type Palette type. One of \code{"regular"}, \code{"sequential"},
 #'   or \code{"diverging"}. See \funclink{tableau_color_pal}.
 #' @inheritParams tableau_color_pal
+#' @param ... Other arguments passed on to \funclink{discrete_scale}.
 #' @family colour tableau
 #' @rdname scale_color_tableau
 #' @export
@@ -76,16 +76,18 @@ tableau_color_pal <- function(palette = "Tableau 10",
 #' @example inst/examples/ex-scale_color_tableau.R
 scale_colour_tableau <- function(palette = "Tableau 10",
                                  type = "regular",
+                                 direction = 1,
                                  ...) {
-  discrete_scale("colour", "tableau", tableau_color_pal(palette, type), ...)
+  discrete_scale("colour", "tableau", tableau_color_pal(palette, type, direction), ...)
 }
 
 #' @export
 #' @rdname scale_color_tableau
 scale_fill_tableau <- function(palette = "Tableau 10",
                                type = "regular",
+                               direction = 1,
                                ...) {
-  discrete_scale("fill", "tableau", tableau_color_pal(palette, type), ...)
+  discrete_scale("fill", "tableau", tableau_color_pal(palette, type, direction), ...)
 }
 
 #' @export
@@ -95,7 +97,7 @@ scale_color_tableau <- scale_colour_tableau
 #' Tableau Shape Palettes (discrete)
 #'
 #' Shape palettes used by
-#' \href{http://www.tableausoftware.com/}{Tableau}.
+#' \href{https://www.tableau.com/}{Tableau}.
 #'
 #' Not all shape palettes in Tableau are supported. Additionally, these
 #' palettes are not exact, and use the best unicode character for the shape
@@ -107,6 +109,8 @@ scale_color_tableau <- scale_colour_tableau
 #' Shape palettes in Tableau are used to expose images for use a markers in
 #' charts, and thus are sometimes groupings of closely related symbols.
 #'
+#' This palette uses unicode symbols. It may not work on all graphics devices.
+#'
 #' @export
 #' @param palette Palette name.
 #' @family shape tableau
@@ -123,6 +127,8 @@ tableau_shape_pal <- function(palette = c("default", "filled", "proportions")) {
 #'
 #' See \code{\link{tableau_shape_pal}()} for details.
 #'
+#' This palette uses unicode symbols. It may not work on all graphics devices.
+#'
 #' @export
 #' @inheritParams tableau_shape_pal
 #' @inheritParams ggplot2::scale_x_discrete
@@ -138,10 +144,10 @@ scale_shape_tableau <- function(palette = "default", ...) {
 #' palettes in Tableau. See \funclink{tableau_color_pal} for discrete color
 #' palettes.
 #'
-#' @param palette Palette name.
-#'  \itemize{
-#'  \item{\code{"ordered-sequential"}}{\Sexpr[results=rd]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["ordered-sequential"]]))}}
-#'  \item{\code{"ordered-diverging"}}{\Sexpr[results=rd]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["ordered-diverging"]]))}}
+#' @param palette Palette name. One of the following:
+#'  \describe{
+#'  \item{Ordered sequential palettes}{\Sexpr[results=rd,stage=build]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["ordered-sequential"]]))}}
+#'  \item{Ordered diverging palettes}{\Sexpr[results=rd,stage=build]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$tableau[["color-palettes"]][["ordered-diverging"]]))}}
 #'  }
 #' @param type Palette type, either \code{"ordered-sequential"} or
 #'   \code{"ordered-diverging"}.
