@@ -1,6 +1,4 @@
-###   (discrete).
-
-
+\dontrun{
 library("ggplot2")
 p <- ggplot(mtcars) +
      geom_point(aes(x = wt, y = mpg, shape = factor(gear))) +
@@ -9,8 +7,5 @@ p <- ggplot(mtcars) +
 # overlapping symbol palette
 p + scale_shape_cleveland()
 # non-overlapping symbol palette
-p + scale_shape_cleveland(overlap=FALSE)
-
-
-
-
+p + scale_shape_cleveland(overlap = FALSE)
+}
\ No newline at end of file
