@@ -1,10 +1,8 @@
-
-
+\dontrun{
 library("ggplot2")
+
 p <- ggplot(mtcars) +
      geom_point(aes(x = wt, y = mpg, shape = factor(gear))) +
      facet_wrap(~am)
 p + theme_stata() + scale_shape_stata()
-
-
-
+}
\ No newline at end of file
