@@ -1,9 +1,8 @@
-context("few")
 library("ggplot2")
 
 test_that("few_shape_pal works", {
   out <- few_shape_pal()
-  expect_is(out, "function")
+  expect_type(out, "closure")
   expect_true(!is.null(attr(out, "max_n")))
 
   pal0 <- out(0)
@@ -16,15 +15,15 @@ test_that("few_shape_pal works", {
 
 test_that("few_shape_pal works", {
   out <- scale_shape_few()
-  expect_is(out, c("ScaleDiscrete", "Scale", "ggproto"))
+  expect_s3_class(out, c("ScaleDiscrete", "Scale", "ggproto"))
 })
 
 test_that("few_pal runs", {
   p <- few_pal("Medium")
-  expect_is(p, "function")
-  expect_is(attr(p, "max_n"), "integer")
+  expect_type(p, "closure")
+  expect_type(attr(p, "max_n"), "integer")
   out <- p(5)
-  expect_is(out, "character")
+  expect_type(out, "character")
   expect_equal(length(out), 5L)
   # should use the first accent color
   expect_equal(out[[1]],
@@ -42,7 +41,7 @@ test_that("few_pal raises error with bad palette", {
 })
 
 test_that("scale_colour_few works", {
-  expect_is(scale_colour_few(), "ScaleDiscrete")
+  expect_s3_class(scale_colour_few(), "ScaleDiscrete")
 })
 
 test_that("scale_color_few works", {
@@ -50,11 +49,11 @@ test_that("scale_color_few works", {
 })
 
 test_that("scale_fill_few works", {
-  expect_is(scale_fill_few(), "ScaleDiscrete")
+  expect_s3_class(scale_fill_few(), "ScaleDiscrete")
 })
 
 test_that("theme_few works", {
-  expect_is(theme_few(), "theme")
+  expect_s3_class(theme_few(), "theme")
 })
 
 test_that("theme_few draws correctly", {
@@ -62,5 +61,5 @@ test_that("theme_few draws correctly", {
   plot <- ggplot(df, aes(x, y, colour = z)) +
     geom_point() +
     facet_wrap(~ a)
-  expect_doppelganger("theme_few", plot + theme_few())
+  expect_doppelganger("theme_few", plot)
 })
