@@ -1,20 +1,18 @@
-context("gdocs")
-
 test_that("gdocs_pal works", {
   pal <- gdocs_pal()
-  expect_is(pal, "function")
+  expect_type(pal, "closure")
   n <- 3
   vals <- pal(n)
-  expect_is(vals, "character")
+  expect_type(vals, "character")
   expect_equal(length(vals), n)
 })
 
 test_that("scale_fill_gdocs works", {
-  expect_is(scale_fill_gdocs(), "ScaleDiscrete")
+  expect_s3_class(scale_fill_gdocs(), "ScaleDiscrete")
 })
 
 test_that("scale_colour_gdocs works", {
-  expect_is(scale_fill_gdocs(), "ScaleDiscrete")
+  expect_s3_class(scale_fill_gdocs(), "ScaleDiscrete")
 })
 
 test_that("scale_color_gdocs works", {
@@ -22,5 +20,5 @@ test_that("scale_color_gdocs works", {
 })
 
 test_that("theme_gdocs works", {
-  expect_is(theme_gdocs(), "theme")
+  expect_s3_class(theme_gdocs(), "theme")
 })
